@@ -75,7 +75,6 @@ class Blueberry(Gtk.Application):
 
         self.window.set_title(_("Bluetooth"))
         self.window.set_icon_name("bluetooth")
-        self.window.connect("destroy", self.terminate)
         self.window.set_default_size(640, 400)
 
         self.main_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
@@ -297,9 +296,6 @@ class Blueberry(Gtk.Application):
         self.rfkill.try_set_blocked(not state)
         return True
 
-    def terminate(self, window):
-        self.rfkill.terminate()
-
 if __name__ == "__main__":
     app = Blueberry()
     app.run(None)
